@@ -1,6 +1,6 @@
 /*
 * dvgrab.cc -- DVGrab control class
-* Copyright (C) 2003 Dan Dennedy <dan@dennedy.org>
+* Copyright (C) 2003-2009 Dan Dennedy <dan@dennedy.org>
 * Major rewrite of code based upon older versions of dvgrab by Arne Schirmacher
 *    and some Kino code also contributed by Charles Yates.
 *
@@ -69,7 +69,7 @@ DVgrab::DVgrab( int argc, char *argv[] ) :
 		m_file_format( DEFAULT_FORMAT ), m_open_dml( false ), m_frame_every( DEFAULT_EVERY ),
 		m_jpeg_quality( 75 ), m_jpeg_deinterlace( false ), m_jpeg_width( -1 ), m_jpeg_height( -1 ),
 		m_jpeg_overwrite( false ), m_jpeg_temp( "dvtmp.jpg" ), m_jpeg_usetemp( false ),
-		m_dropped_frames( 0 ), m_interactive( false ), m_buffers( DEFAULT_BUFFERS ), m_total_frames( 0 ),
+		m_dropped_frames( 0 ), m_bad_frames(0), m_interactive( false ), m_buffers( DEFAULT_BUFFERS ), m_total_frames( 0 ),
 		m_duration( "" ), m_timeDuration( 0 ), m_noavc( false ),
 		m_guid( 0 ), m_timesys( false ), m_connection( 0 ), m_raw_pipe( false ),
 		m_no_stop( false ), m_timecode( false ), m_lockstep( false ), m_lockPending( false ),
@@ -193,9 +193,9 @@ void DVgrab::print_help()
 	cerr << "              raw         raw DV file with a .dv extension" << endl;
 	cerr << "              dif         raw DV file with a .dif extension" << endl;
 	cerr << "              dv1         'Type 1' DV AVI file" << endl;
-	cerr << "              dv2         'Type 2' DV AVI file" << endl;
+	cerr << "              dv2, avi    'Type 2' DV AVI file" << endl;
 #ifdef HAVE_LIBQUICKTIME
-	cerr << "              qt          QuickTime DV movie" << endl;
+	cerr << "              qt, mov     QuickTime DV movie" << endl;
 #endif
 	cerr << "              mpeg2, hdv  MPEG-2 transport stream (HDV)" << endl;
 #if defined(HAVE_LIBJPEG) && defined(HAVE_LIBDV)
@@ -254,11 +254,11 @@ void DVgrab::set_file_format( char *format )
 {
 	if ( strcmp( "dv1", format ) == 0 )
 		m_file_format = AVI_DV1_FORMAT;
-	else if ( strcmp( "dv2", format ) == 0 )
+	else if ( strcmp( "dv2", format ) == 0 || strcmp( "avi", format ) == 0 )
 		m_file_format = AVI_DV2_FORMAT;
 	else if ( strcmp( "raw", format ) == 0 )
 		m_file_format = RAW_FORMAT;
-	else if ( strcmp( "qt", format ) == 0 )
+	else if ( strcmp( "qt", format ) == 0 || strcmp( "mov", format ) == 0 )
 		m_file_format = QT_FORMAT;
 	else if ( strcmp( "dif", format ) == 0 )
 		m_file_format = DIF_FORMAT;
@@ -593,20 +593,24 @@ void DVgrab::startCapture()
 				AVC1394_MASK_RESPONSE_OPERAND( m_avc->TransportStatus( m_node ), 3 )
 				!= AVC1394_VCR_OPERAND_WIND_STOP )
 			{
-				timespec t = {0, 25000000UL};
+				timespec t = {0, 125000000L};
 				nanosleep( &t, NULL );
 			}
 
 			// Rewind
 			if ( !g_done )
+			{
 				m_avc->Rewind( m_node );
+				timespec t = {0, 125000000L};
+				nanosleep( &t, NULL );
+			}
 
 			// Wait until is done rewinding
 			while ( !g_done &&
 			        AVC1394_MASK_RESPONSE_OPERAND( m_avc->TransportStatus( m_node ), 3 )
 			            != AVC1394_VCR_OPERAND_WIND_STOP )
 			{
-				timespec t = {0, 25000000UL};
+				timespec t = {0, 125000000L};
 				nanosleep( &t, NULL );
 			}
 		}
@@ -620,7 +624,7 @@ void DVgrab::startCapture()
 	// this is a little unclean, checking global g_done from main.cc to allow interruption
 	while ( !g_done && m_frame == NULL && tryCounter-- > 0 )
 	{
-		timespec t = {0, 25000000UL};
+		timespec t = {0, 25000000L};
 		nanosleep( &t, NULL );
 	}
 
@@ -696,7 +700,10 @@ void DVgrab::stopCapture()
 
 		if ( m_dropped_frames > 0 )
 			sendEvent( "Warning: %d dropped frames.", m_dropped_frames );
+		if ( m_bad_frames > 0 )
+			sendEvent( "Warning: %d damaged frames.", m_bad_frames );
 		m_dropped_frames = 0;
+		m_bad_frames = 0;
 		m_captureActive = false;
 	}
 	pthread_mutex_unlock( &capture_mutex );
@@ -891,6 +898,9 @@ void DVgrab::writeFrame()
 			if ( m_dropped_frames > 0 )
 				sendEvent( "Warning: %d dropped frames.", m_dropped_frames );
 			m_dropped_frames = 0;
+			if ( m_bad_frames > 0 )
+				sendEvent( "Warning: %d damaged frames.", m_bad_frames );
+			m_bad_frames = 0;
 		}
 		else if ( m_showstatus )
 		{
@@ -944,7 +954,7 @@ void DVgrab::sendFrameDroppedStatus( const char *reason, const char *meaning )
 		sprintf( rd, "????.??.?? ??:??:??" );
 
 	sendEvent( "\n\a\"%s\": %s: timecode %s date %s",
-		m_writer ? m_writer->GetFileName().c_str() : "stdout", reason, tc, rd );
+		m_writer ? m_writer->GetFileName().c_str() : "", reason, tc, rd );
 
 	sendEvent( meaning );
 }
@@ -962,6 +972,7 @@ void DVgrab::captureThreadRun()
 		m_reader->WaitForAction( );
 
 		int dropped = m_reader->GetDroppedFrames();
+		int badFrames = m_reader->GetBadFrames();
 
 		// Get the next frame
 		if ( ( m_frame = m_reader->GetFrame() ) == NULL )
@@ -996,7 +1007,12 @@ void DVgrab::captureThreadRun()
 					m_dropped_frames = 0;
 				}
 			}
-
+		}
+		if ( badFrames > 0 )
+		{
+			m_bad_frames += badFrames;
+			sendFrameDroppedStatus( "damaged frame near",
+				"This means that there were missing or invalid FireWire packets." );
 		}
 
 		if ( ! m_frame->IsComplete() )
@@ -1038,7 +1054,7 @@ void DVgrab::captureThreadRun()
 				       !m_avc ||
 				       !m_isRecordMode ||
 				       ( m_isRecordMode &&
-				         strcmp( avc1394_vcr_decode_status( m_avc->TransportStatus( m_node ) ), "Recording" ) == 0 &&
+				         strcmp( avc1394_vcr_decode_status( m_transportStatus ), "Recording" ) == 0 &&
 				         !( timeCode.hour == 0 && timeCode.min == 0  && timeCode.sec == 0 && timeCode.frame == 0 )
 				       )
 				     )
@@ -1074,7 +1090,7 @@ void DVgrab::status( )
 	unsigned int status;
 	static unsigned int prevStatus = 0;
 	std::string transportStatus( "" );
-	std::string timecode( "" );
+	std::string timecode( "--:--:--:--" );
 	std::string filename( "" );
 	std::string duration( "" );
 
@@ -1268,9 +1284,8 @@ bool DVgrab::isPlaying()
 {
 	if ( ! m_avc )
 		return false;
-	unsigned int status = m_avc->TransportStatus( m_node );
-	quadlet_t resp2 = AVC1394_MASK_RESPONSE_OPERAND( status, 2 );
-	quadlet_t resp3 = AVC1394_MASK_RESPONSE_OPERAND( status, 3 );
+	quadlet_t resp2 = AVC1394_MASK_RESPONSE_OPERAND( m_transportStatus, 2 );
+	quadlet_t resp3 = AVC1394_MASK_RESPONSE_OPERAND( m_transportStatus, 3 );
 	return ( ( resp2 == AVC1394_VCR_RESPONSE_TRANSPORT_STATE_PLAY && resp3 != AVC1394_VCR_OPERAND_PLAY_FORWARD_PAUSE ) ||
 		( resp2 == AVC1394_VCR_RESPONSE_TRANSPORT_STATE_RECORD && resp3 != AVC1394_VCR_OPERAND_RECORD_PAUSE ) );
 }
@@ -1280,13 +1295,15 @@ bool DVgrab::done()
 	if ( m_reader_active )
 	{
 		// Stop capture at end of tape
-		if ( !m_interactive && m_writer && m_writer->GetFileSize() > 0 && m_avc &&
-		     AVC1394_MASK_RESPONSE_OPERAND( m_avc->TransportStatus( m_node ), 3 ) == AVC1394_VCR_OPERAND_WIND_STOP )
+		if ( !m_interactive && m_writer && m_writer->GetFileSize() > 0 && m_avc && !m_isRecordMode )
 		{
+			m_transportStatus = m_avc->TransportStatus( m_node );
+			if ( AVC1394_MASK_RESPONSE_OPERAND( m_transportStatus, 3 ) == AVC1394_VCR_OPERAND_WIND_STOP
+			     && AVC1394_MASK_OPCODE( m_transportStatus ) == AVC1394_VCR_RESPONSE_TRANSPORT_STATE_WIND )
 			return true;
 		}
 		
-		timespec t = {0, 25000000};
+		timespec t = {0, 125000000L};
 		return ( nanosleep( &t, NULL ) == -1 );
 	}
 	return true;
