@@ -1,7 +1,7 @@
 /*
 * filehandler.cc -- saving DV data into different file formats
 * Copyright (C) 2000 Arne Schirmacher <arne@schirmacher.de>
-* Raw DV, JPEG, and Quicktime portions Copyright (C) 2003 Dan Dennedy <dan@dennedy.org>
+* Raw DV, JPEG, and Quicktime portions Copyright (C) 2003-2008 Dan Dennedy <dan@dennedy.org>
 * Portions of Quicktime code borrowed from Arthur Peters' dv_utils.
 *
 * This program is free software; you can redistribute it and/or modify
@@ -44,6 +44,7 @@ using std::ends;
 #include <time.h>
 #include <errno.h>
 #include <string.h>
+#include <stdlib.h>
 
 #include "filehandler.h"
 #include "error.h"
@@ -396,7 +397,7 @@ bool FileHandler::WriteFrame( Frame *frame )
 				<< setw( 2 ) << date.tm_mday << '_'
 				<< setw( 2 ) << date.tm_hour << '-'
 				<< setw( 2 ) << date.tm_min << '-'
-				<< setw( 2 ) << date.tm_sec << ends;
+				<< setw( 2 ) << date.tm_sec;
 				recDate = sb.str();
 			}
 			else
@@ -898,9 +899,10 @@ int QtHandler::Write( Frame *f )
 		if ( frame->GetAudioInfo( audio ) )
 		{
 			/* TODO: handle 12-bit, non-linear audio */
+			char compressor[] = QUICKTIME_TWOS;
 			channels = 2;
 			quicktime_set_audio( fd, channels, audio.frequency, 16,
-			                     QUICKTIME_TWOS );
+			                     compressor );
 		}
 		else
 		{
@@ -909,12 +911,14 @@ int QtHandler::Write( Frame *f )
 
 		if ( filmRate || remove2332 )
 		{
-			quicktime_set_video( fd, 1, 720, 480, 24, QUICKTIME_DV );
+			char compressor[] = QUICKTIME_DV;
+			quicktime_set_video( fd, 1, 720, 480, 24, compressor );
 		}
 		else
 		{
+			char compressor[] = QUICKTIME_DV;
 			quicktime_set_video( fd, 1, 720, frame->IsPAL() ? 576 : 480,
-			                     frame->GetFrameRate(), QUICKTIME_DV );
+			                     frame->GetFrameRate(), compressor );
 		}
 
 		if ( channels > 0 )
