@@ -1,6 +1,7 @@
 /*
 * ieee1394io.cc -- asynchronously grabbing DV data
 * Copyright (C) 2000 Arne Schirmacher <arne@schirmacher.de>
+* Copyright (C) 2003-2009 Dan Dennedy <dan@dennedy.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -90,6 +91,7 @@ using std::endl;
 
 IEEE1394Reader::IEEE1394Reader( int c, int bufSize, bool hdv ) :
 	droppedFrames( 0 ),
+	badFrames( 0 ),
 	currentFrame( NULL ),
 	channel( c ),
 	isRunning( false ),
@@ -208,6 +210,19 @@ int IEEE1394Reader::GetDroppedFrames( void )
 }
 
 
+/** Return the number of incomplete frames since last call
+*/
+
+int IEEE1394Reader::GetBadFrames( void )
+{
+	pthread_mutex_lock( &mutex );
+	int n = badFrames;
+	badFrames = 0;
+	pthread_mutex_unlock( &mutex );
+	return n;
+}
+
+
 /** Throw away all currently available frames.
  
     All frames in the outFrames queue are put back to the inFrames
@@ -503,7 +518,7 @@ int iec61883Reader::DvHandlerProxy( unsigned char *data, int length,
 
 int iec61883Reader::Handler( unsigned char *data, int length, int dropped )
 {
-	droppedFrames += dropped;
+	badFrames += dropped;
 
 	if ( currentFrame == NULL )
 	{
@@ -774,7 +789,7 @@ int AVC::Pause( int phyID )
 	}
 	struct timespec t =
 	    {
-		    0, 250000000
+		    0, 250000000L
 	    };
 	nanosleep( &t, NULL );
 	pthread_mutex_unlock( &avc_mutex );
@@ -792,7 +807,7 @@ int AVC::Stop( int phyID )
 	}
 	struct timespec t =
 	    {
-		    0, 250000000
+		    0, 250000000L
 	    };
 	nanosleep( &t, NULL );
 	pthread_mutex_unlock( &avc_mutex );
@@ -912,6 +927,7 @@ unsigned int AVC::TransportStatus( int phyID )
 
 bool AVC::Timecode( int phyID, char* timecode )
 {
+	bool result = false;
 	pthread_mutex_lock( &avc_mutex );
 	if ( avc_handle != NULL )
 	{
@@ -924,22 +940,20 @@ bool AVC::Timecode( int phyID, char* timecode )
 			               AVC1394_VCR_COMMAND_TIME_CODE | AVC1394_VCR_OPERAND_TIME_CODE_STATUS;
 			request[ 1 ] = 0xFFFFFFFF;
 			response = avc1394_transaction_block( avc_handle, phyID, request, 2, 1 );
-			if ( response == NULL )
+			if ( response && response[1] != 0xffffffff )
 			{
-				pthread_mutex_unlock( &avc_mutex );
-				return false;
-			}
-
-			sprintf( timecode, "%2.2x:%2.2x:%2.2x:%2.2x",
+				sprintf( timecode, "%2.2x:%2.2x:%2.2x:%2.2x",
 			         response[ 1 ] & 0x000000ff,
 			         ( response[ 1 ] >> 8 ) & 0x000000ff,
 			         ( response[ 1 ] >> 16 ) & 0x000000ff,
 			         ( response[ 1 ] >> 24 ) & 0x000000ff );
+				result = true;
+			}
 		}
 
 	}
 	pthread_mutex_unlock( &avc_mutex );
-	return true;
+	return result;
 }
 
 int AVC::getNodeId( const char *guid )
