@@ -1,6 +1,7 @@
 /*
 * ieee1394io.cc -- asynchronously grabbing DV data
 * Copyright (C) 2000 Arne Schirmacher <arne@schirmacher.de>
+* Copyright (C) 2003-2008 Dan Dennedy <dan@dennedy.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -40,6 +41,7 @@ protected:
 	/// the number of frames that had to be thrown away because
 	/// our inFrames queue did not contain available frames
 	int droppedFrames;
+	int badFrames;
 
 	/// a pointer to the frame which is currently been transmitted
 	Frame	*currentFrame;
@@ -61,6 +63,7 @@ public:
 	Frame* GetFrame( void );
 	void DoneWithFrame( Frame* );
 	int GetDroppedFrames( void );
+	int GetBadFrames( void );
 	int GetOutQueueSize( void )
 	{
 		return outFrames.size();
