@@ -1,7 +1,7 @@
 /*
 * main.cc -- A DV/1394 capture utility
-* Orginally Copyright (C) 2000 - 2002 Arne Schirmacher <arne@schirmacher.de>
-* This portion rewritten by and Copyright (C) 2003 Dan Dennedy <dan@dennedy.org>
+* Copyright (C) 2000-2002 Arne Schirmacher <arne@schirmacher.de>
+* Copyright (C) 2003-2008 Dan Dennedy <dan@dennedy.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ int rt_raisepri (int pri)
 	 */
 	if ( sysconf( _SC_PRIORITY_SCHEDULING ) == -1)
 	{
-		sendEvent( "Warning: RR-scheduler not available, disabling." );
+// 		sendEvent( "Warning: RR-scheduler not available, disabling." );
 		return -1;
 	}
 	else 
@@ -80,7 +80,7 @@ int rt_raisepri (int pri)
 		scp.sched_priority = sched_get_priority_max( SCHED_RR ) - pri;
 		if ( sched_setscheduler( 0, SCHED_RR, &scp ) < 0 )
 		{
-			sendEvent( "Warning: Cannot set RR-scheduler" );
+// 			sendEvent( "Warning: Cannot set RR-scheduler" );
 			return -1;
 		}
 	}
@@ -108,8 +108,7 @@ int main( int argc, char *argv[] )
 			setpriority( PRIO_PROCESS, 0, -20 );
 
 #if _POSIX_MEMLOCK > 0
-		if ( mlockall( MCL_CURRENT | MCL_FUTURE ) == -1 )
-			sendEvent( "Warning: Cannot disable swapping" );
+		mlockall( MCL_CURRENT | MCL_FUTURE );
 #endif
 
 		if ( dvgrab.isInteractive() )
